/*****************************************************************
 *  File Name:  EDGE_CONTRAST.C
 *
 *  Purpose:   This program is called by the arc/info aml, 
 *	indices.aml to calculate the edge contrast index.  The 
 *	name of the file of weights is passed as a command line
 *	argument.  The file temp.dat is written out by indices.aml
 *	and contains class numbers of the polygon to the right and
 *	left of the line segment of interest, the length  of the 
 *      line segment, and the perimeter of the polygon of which the
 *	the line is a part.  The file contains records for all the
 *	line segments making up the polygon.  The value of the edge
 *	contrast index is written to the file edgecon.dat.
 *
 *  File Formats:
 *	File of weights: 
 *		integer class no, integer class no, float weight
 *	        Example:
 *		   1,2,.91
 *		   1,3,.87
 *		   2,3,.5
 *
 *	temp.dat
 *		integer class no, integer class no, float line
 *		   length, float perimeter
 *		Example:
 *		   2,10,132.4,1663.7
 *		   10,4,77.3,1663.7
 *
 *  Programmer:  Barbara Marks
 *
 *  Date:  December, 1991
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>


main(argc,argv)
int	argc;
char	*argv[];
{
	FILE	*fp;
	int	class1,class2;
	int	v1,v2;
	int	i;
	float	v3;
	float	len;
	float	ins;
	float 	dissimilar[100][100];
	char	string[80];
	char	filename[60];
	char	in_file[60];
	char	out_file[60];

  

        if (argc != 4) {
	   printf ("\nUsage: edge_contrast weight_file in_file out_file");
	   exit(-1);
	}
	strcpy (filename,argv[1]);
	strcpy (in_file,argv[2]);
	strcpy (out_file,argv[3]);

/*
 *  Set up the dissimilar array so that the weight of class
 *  1 vs 1 is 0, 2 vs 2 is 0, etc.
 */
	for (i=0; i < 100; i++)  dissimilar[i][i] = 0.0;

/*
 *  The name of the file containing the weights is passed
 *  as argument 1.  Open the file and read it.
 */
	strcpy (filename,argv[1]);
	fp = fopen (filename,"r");
	while (!feof(fp)) {
                fscanf (fp,"%d,%d,%f",&v1,&v2,&v3);
                if (feof(fp)) break;
                dissimilar[v1][v2] = v3;
                dissimilar[v2][v1] = v3;
        }
        fclose (fp);

/*
 *  Open the data file.  This file is created by the
 *  arc/info aml fragstats.aml.  It contains:  class# of the
 *  polygon to the left of the line segment, class# of the
 *  polygon to the right of the line segment, the length
 *  of the line segment, and the perimeter of the polygon
 *  of interest.  Read in data for all lines that make up
 *  the polygon of interest, summing the weight * the length.
 */
	if ((fp = fopen(in_file,"r")) == NULL) {
	   printf ("\nERROR! Can not open file: %s\n",in_file);
	   exit(-1);
	}

	ins = 0.0;
	while (!feof(fp)) {
		fgets (string,80,fp);	
		if (feof(fp)) break;
		class1 = atoi (strtok(string," ,"));
		class2 = atoi (strtok('\0'," ,"));
		len = atof (strtok('\0'," ,"));

		if (class1 == -999 && class2 == -999) 
		   ins += len;
                else
		   ins += (dissimilar[class1][class2] * len);
	}
	fclose (fp);

/*
 *  Calculate the edge contrast index and write it to the file
 *  edgecon.dat
 */

	if ((fp = fopen (out_file,"w")) == NULL) {
	   printf ("\nERROR! Can not open file: %s\n",out_file);
	   exit(-1);
	}

	fprintf (fp,"%f\n",ins);
	fclose (fp);

}

